@@ -25,9 +25,8 @@ def _time(signal, dB=False, log_prefix=20, log_reference=1, unit=None,
         # avoid any zero-values because they result in -inf in dB data
         eps = np.finfo(float).eps
         data = log_prefix * np.log10(np.abs(data) / log_reference + eps)
-        ymax = np.nanmax(data)
-        ymin = ymax - 90
-        ymax = ymax + 10
+        ymax = np.nanmax(data) + 10
+        ymin = ymax - 100
 
     # auto detect the time unit
     if unit is None:
@@ -56,7 +55,7 @@ def _time(signal, dB=False, log_prefix=20, log_reference=1, unit=None,
     return ax
 
 
-def _freq(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
+def _freq(signal, dB=True, log_prefix=None, log_reference=1, freq_scale='log',
           ax=None, **kwargs):
     """
     Plot the logarithmic absolute spectrum on the positive frequency axis.
@@ -66,7 +65,7 @@ def _freq(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
     if not isinstance(signal, (Signal, FrequencyData)):
         raise TypeError(
             'Input data has to be of type: Signal or FrequencyData.')
-    _utils._check_axis_scale(xscale)
+    _utils._check_axis_scale(freq_scale)
 
     # prepare input
     kwargs = _utils._return_default_colors_rgb(**kwargs)
@@ -94,27 +93,28 @@ def _freq(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
                       signal.frequencies[-1], ax.get_xlim())
 
     # plot data
-    if xscale == 'log':
+    if freq_scale == 'log':
         ax.semilogx(signal.frequencies, data.T, **kwargs)
     else:
         ax.plot(signal.frequencies, data.T, **kwargs)
 
     # set and format ticks
-    if xscale == 'log':
+    if freq_scale == 'log':
         ax.xaxis.set_major_locator(LogLocatorITAToolbox())
     ax.xaxis.set_major_formatter(LogFormatterITAToolbox())
 
     return ax
 
 
-def _phase(signal, deg=False, unwrap=False, xscale='log', ax=None, **kwargs):
+def _phase(signal, deg=False, unwrap=False, freq_scale='log', ax=None,
+           **kwargs):
     """Plot the phase of the spectrum on the positive frequency axis."""
 
     # check input
     if not isinstance(signal, (Signal, FrequencyData)):
         raise TypeError(
             'Input data has to be of type: Signal or FrequencyData.')
-    _utils._check_axis_scale(xscale)
+    _utils._check_axis_scale(freq_scale)
 
     # prepare figure
     _, ax = _utils._prepare_plot(ax)
@@ -122,28 +122,20 @@ def _phase(signal, deg=False, unwrap=False, xscale='log', ax=None, **kwargs):
     # prepare input
     kwargs = _utils._return_default_colors_rgb(**kwargs)
     phase_data = dsp.phase(signal, deg=deg, unwrap=unwrap)
-    # Construct the correct label string:
-    ylabel_string = 'Phase '
-    if unwrap == '360':
-        ylabel_string += '(wrapped to 360) '
-    elif unwrap is True:
-        ylabel_string += '(unwrapped) '
-    elif not isinstance(unwrap, bool):
-        raise ValueError(f"unwrap is {unwrap} but must be True, False, or 360")
 
-    if deg:
-        ylabel_string += 'in degree'
-        y_margin = 5
-    else:
-        ylabel_string += 'in radians'
+    # Construct the correct label string
+    ylabel_string = _utils._phase_label(unwrap, deg)
+
+    # y-axis formatting
+    y_margin = 5 if deg else np.radians(5)
+    if not deg and (not unwrap or unwrap == "360"):
         # nice tick formatting is not done for unwrap=True. In this case
         # it can create 1000 or more ticks.
-        if not unwrap or unwrap == "360":
-            ax.yaxis.set_major_locator(MultipleFractionLocator(np.pi, 2))
-            ax.yaxis.set_minor_locator(MultipleFractionLocator(np.pi, 6))
-            ax.yaxis.set_major_formatter(MultipleFractionFormatter(
-                nominator=1, denominator=2, base=np.pi, base_str=r'\pi'))
-        y_margin = np.radians(5)
+        ax.yaxis.set_major_locator(MultipleFractionLocator(np.pi, 2))
+        ax.yaxis.set_minor_locator(MultipleFractionLocator(np.pi, 6))
+        ax.yaxis.set_major_formatter(MultipleFractionFormatter(
+            nominator=1, denominator=2, base=np.pi, base_str=r'\pi'))
+
     ymin = np.nanmin(phase_data) - y_margin  # more elegant solution possible?
     ymax = np.nanmax(phase_data) + y_margin
 
@@ -156,27 +148,27 @@ def _phase(signal, deg=False, unwrap=False, xscale='log', ax=None, **kwargs):
     _utils._set_axlim(ax, ax.set_ylim, ymin, ymax, ax.get_ylim())
 
     # plot data
-    if xscale == 'log':
+    if freq_scale == 'log':
         ax.semilogx(signal.frequencies, phase_data.T, **kwargs)
     else:
         ax.plot(signal.frequencies, phase_data.T, **kwargs)
 
     # set and format ticks
-    if xscale == 'log':
+    if freq_scale == 'log':
         ax.xaxis.set_major_locator(LogLocatorITAToolbox())
     ax.xaxis.set_major_formatter(LogFormatterITAToolbox())
 
     return ax
 
 
-def _group_delay(signal, unit=None, xscale='log', ax=None, **kwargs):
+def _group_delay(signal, unit=None, freq_scale='log', ax=None, **kwargs):
     """Plot the group delay on the positive frequency axis."""
 
     # check input
     if not isinstance(signal, Signal):
         raise TypeError('Input data has to be of type: Signal.')
     _utils._check_time_unit(unit)
-    _utils._check_axis_scale(xscale)
+    _utils._check_axis_scale(freq_scale)
 
     # prepare input
     kwargs = _utils._return_default_colors_rgb(**kwargs)
@@ -201,13 +193,13 @@ def _group_delay(signal, unit=None, xscale='log', ax=None, **kwargs):
                       1.5 * np.nanmax(data), ax.get_ylim())
 
     # plot data
-    if xscale == 'log':
+    if freq_scale == 'log':
         ax.semilogx(signal.frequencies, data.T, **kwargs)
     else:
         ax.plot(signal.frequencies, data.T, **kwargs)
 
     # set and format ticks
-    if xscale == 'log':
+    if freq_scale == 'log':
         ax.xaxis.set_major_locator(LogLocatorITAToolbox())
     ax.xaxis.set_major_formatter(LogFormatterITAToolbox())
 
@@ -215,8 +207,8 @@ def _group_delay(signal, unit=None, xscale='log', ax=None, **kwargs):
 
 
 def _time_freq(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
-               log_prefix_freq=None, log_reference=1, xscale='log', unit=None,
-               ax=None, **kwargs):
+               log_prefix_freq=None, log_reference=1, freq_scale='log',
+               unit=None, ax=None, **kwargs):
     """
     Plot the time signal and magnitude spectrum in a 2 by 1 subplot layout.
     """
@@ -226,7 +218,7 @@ def _time_freq(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
 
     _time(signal, dB_time, log_prefix_time, log_reference, unit, ax[0],
           **kwargs)
-    _freq(signal, dB_freq, log_prefix_freq, log_reference, xscale, ax[1],
+    _freq(signal, dB_freq, log_prefix_freq, log_reference, freq_scale, ax[1],
           **kwargs)
     fig.align_ylabels()
 
@@ -234,14 +226,14 @@ def _time_freq(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
 
 
 def _freq_phase(signal, dB=True, log_prefix=None, log_reference=1,
-                xscale='log', deg=False, unwrap=False, ax=None, **kwargs):
+                freq_scale='log', deg=False, unwrap=False, ax=None, **kwargs):
     """Plot the magnitude and phase spectrum in a 2 by 1 subplot layout."""
 
     fig, ax = _utils._prepare_plot(ax, (2, 1))
     kwargs = _utils._return_default_colors_rgb(**kwargs)
 
-    _freq(signal, dB, log_prefix, log_reference, xscale, ax[0], **kwargs)
-    _phase(signal, deg, unwrap, xscale, ax[1], **kwargs)
+    _freq(signal, dB, log_prefix, log_reference, freq_scale, ax[0], **kwargs)
+    _phase(signal, deg, unwrap, freq_scale, ax[1], **kwargs)
     ax[0].set_xlabel(None)
     fig.align_ylabels()
 
@@ -249,7 +241,7 @@ def _freq_phase(signal, dB=True, log_prefix=None, log_reference=1,
 
 
 def _freq_group_delay(signal, dB=True, log_prefix=None, log_reference=1,
-                      unit=None, xscale='log', ax=None, **kwargs):
+                      unit=None, freq_scale='log', ax=None, **kwargs):
     """
     Plot the magnitude and group delay spectrum in a 2 by 1 subplot layout.
     """
@@ -257,8 +249,8 @@ def _freq_group_delay(signal, dB=True, log_prefix=None, log_reference=1,
     fig, ax = _utils._prepare_plot(ax, (2, 1))
     kwargs = _utils._return_default_colors_rgb(**kwargs)
 
-    _freq(signal, dB, log_prefix, log_reference, xscale, ax[0], **kwargs)
-    _group_delay(signal, unit, xscale, ax[1], **kwargs)
+    _freq(signal, dB, log_prefix, log_reference, freq_scale, ax[0], **kwargs)
+    _group_delay(signal, unit, freq_scale, ax[1], **kwargs)
     ax[0].set_xlabel(None)
     fig.align_ylabels()
 
