@@ -1,6 +1,7 @@
 from pyfar.plot.utils import context
 from . import (_line, _utils)
 from . import _interaction as ia
+import warnings
 
 
 def time(signal, dB=False, log_prefix=20, log_reference=1, unit=None, ax=None,
@@ -27,9 +28,10 @@ def time(signal, dB=False, log_prefix=20, log_reference=1, unit=None, ax=None,
         Reference for calculating the logarithmic time data. The default is
         ``1``.
     unit : str, None
-        Unit of the time axis. Can be ``s``, ``ms``, ``mus``, or ``samples``.
+        Unit of the time axis. Can be ``'s'``, ``'ms'``, ``'mus'``, or
+        ``'samples'``.
         The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milli seconds), or ``mus`` (micro seconds) depending on the data.
+        (milliseconds), or ``mus`` (microseconds) depending on the data.
     ax : matplotlib.pyplot.axes
         Axes to plot on. The default is ``None``, which uses the current axis
         or creates a new figure if none exists.
@@ -63,15 +65,16 @@ def time(signal, dB=False, log_prefix=20, log_reference=1, unit=None, ax=None,
     # manage interaction
     plot_parameter = ia.PlotParameter(
         'time', dB_time=dB, log_prefix_time=log_prefix,
-        log_reference=log_reference)
-    interaction = ia.Interaction(signal, ax, style, plot_parameter, **kwargs)
+        log_reference=log_reference, unit_time=unit)
+    interaction = ia.Interaction(
+        signal, ax, None, style, plot_parameter, **kwargs)
     ax.interaction = interaction
 
     return ax
 
 
-def freq(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
-         ax=None, style='light', **kwargs):
+def freq(signal, dB=True, log_prefix=None, log_reference=1, freq_scale='log',
+         ax=None, style='light', xscale=None, **kwargs):
     """
     Plot the magnitude spectrum.
 
@@ -95,7 +98,7 @@ def freq(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
     log_reference : integer, float
         Reference for calculating the logarithmic frequency data. The default
         is ``1``.
-    xscale : str
+    freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
     ax : matplotlib.pyplot.axes
@@ -104,6 +107,16 @@ def freq(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
     style : str
         ``light`` or ``dark`` to use the pyfar plot styles or a plot style from
         ``matplotlib.style.available``. The default is ``light``.
+    xscale : str
+
+        .. deprecated:: 0.4.0
+
+        This parameter was replaced by the more explicit ``freq_scale``,
+        which has the same functionality.
+        If not ``None``, it overwrites ``freq_scale``.
+        It is kept for backwards compatibility until pyfar version 0.6.0.
+
+        The default is ``None``.
     **kwargs
         Keyword arguments that are passed to ``matplotlib.pyplot.plot()``.
 
@@ -122,23 +135,31 @@ def freq(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
         >>> pf.plot.freq(sine)
     """
 
+    # xscale deprecation
+    if xscale is not None:
+        warnings.warn(('The xscale parameter will be removed in'
+                       'pyfar 0.6.0. in favor of freq_scale'),
+                      PendingDeprecationWarning)
+        freq_scale = xscale
+
     with context(style):
         ax = _line._freq(signal.flatten(), dB, log_prefix, log_reference,
-                         xscale, ax, **kwargs)
+                         freq_scale, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
         'freq', dB_freq=dB, log_prefix_freq=log_prefix,
-        log_reference=log_reference, xscale=xscale)
-    interaction = ia.Interaction(signal, ax, style, plot_parameter, **kwargs)
+        log_reference=log_reference, xscale=freq_scale)
+    interaction = ia.Interaction(
+        signal, ax, None, style, plot_parameter, **kwargs)
     ax.interaction = interaction
 
     return ax
 
 
-def phase(signal, deg=False, unwrap=False, xscale='log', ax=None,
-          style='light', **kwargs):
+def phase(signal, deg=False, unwrap=False, freq_scale='log', ax=None,
+          style='light', xscale=None, **kwargs):
     """Plot the phase of the spectrum.
 
     Plots ``angle(signal.freq)`` and passes keyword arguments (`kwargs`) to
@@ -154,9 +175,9 @@ def phase(signal, deg=False, unwrap=False, xscale='log', ax=None,
         Plot the phase in degrees. The default is ``False``, which plots the
         phase in radians.
     unwrap : bool, str
-        True to unwrap the phase or "360" to unwrap the phase to 2 pi. The
+        True to unwrap the phase or ``'360'`` to unwrap the phase to 2 pi. The
         default is ``False``, which plots the wrapped phase.
-    xscale : str
+    freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
     ax : matplotlib.pyplot.axes object
@@ -165,6 +186,16 @@ def phase(signal, deg=False, unwrap=False, xscale='log', ax=None,
     style : str
         ``light`` or ``dark`` to use the pyfar plot styles or a plot style from
         ``matplotlib.style.available``. The default is ``light``.
+    xscale : str
+
+        .. deprecated:: 0.4.0
+
+        This parameter was replaced by the more explicit ``freq_scale``,
+        which has the same functionality.
+        If not ``None``, it overwrites ``freq_scale``.
+        It is kept for backwards compatibility until pyfar version 0.6.0.
+
+        The default is ``None``.
     **kwargs
         Keyword arguments that are passed to ``matplotlib.pyplot.plot()``.
 
@@ -183,24 +214,34 @@ def phase(signal, deg=False, unwrap=False, xscale='log', ax=None,
         >>> pf.plot.phase(impulse, unwrap=True)
     """
 
+    # xscale deprecation
+    if xscale is not None:
+        warnings.warn(('The xscale parameter will be removed in'
+                       'pyfar 0.6.0. in favor of freq_scale'),
+                      PendingDeprecationWarning)
+        freq_scale = xscale
+
     with context(style):
-        ax = _line._phase(signal.flatten(), deg, unwrap, xscale, ax, **kwargs)
+        ax = _line._phase(
+            signal.flatten(), deg, unwrap, freq_scale, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
-        'phase', deg=deg, unwrap=unwrap, xscale=xscale)
-    interaction = ia.Interaction(signal, ax, style, plot_parameter, **kwargs)
+        'phase', deg=deg, unwrap=unwrap, xscale=freq_scale)
+    interaction = ia.Interaction(
+        signal, ax, None, style, plot_parameter, **kwargs)
     ax.interaction = interaction
 
     return ax
 
 
-def group_delay(signal, unit=None, xscale='log', ax=None, style='light',
-                **kwargs):
+def group_delay(signal, unit=None, freq_scale='log', ax=None, style='light',
+                xscale=None, **kwargs):
     """Plot the group delay.
 
-    Passes keyword arguments (`kwargs`) to ``matplotlib.pyplot.plot()``.
+    Plots ``pyfar.dsp.group_delay(signal.freq)`` and passes keyword arguments
+    (`kwargs`) to ``matplotlib.pyplot.plot()``.
 
     Parameters
     ----------
@@ -209,10 +250,11 @@ def group_delay(signal, unit=None, xscale='log', ax=None, style='light',
         plotting, e.g, a signal of ``signal.cshape = (2, 2)`` would be plotted
         in the order ``(0, 0)``, ``(0, 1)``, ``(1, 0)``, ``(1, 1)``.
     unit : str, None
-        Unit of the group delay. Can be ``s``, ``ms``, ``mus``, or ``samples``.
+        Unit of the group delay. Can be ``'s'``, ``'ms'``, ``'mus'``, or
+        ``'samples'``.
         The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milli seconds), or ``mus`` (micro seconds) depending on the data.
-    xscale : str
+        (milliseconds), or ``mus`` (microseconds) depending on the data.
+    freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
     ax : matplotlib.pyplot.axes
@@ -221,6 +263,16 @@ def group_delay(signal, unit=None, xscale='log', ax=None, style='light',
     style : str
         ``light`` or ``dark`` to use the pyfar plot styles or a plot style from
         ``matplotlib.style.available``. The default is ``light``.
+    xscale : str
+
+        .. deprecated:: 0.4.0
+
+        This parameter was replaced by the more explicit ``freq_scale``,
+        which has the same functionality.
+        If not ``None``, it overwrites ``freq_scale``.
+        It is kept for backwards compatibility until pyfar version 0.6.0.
+
+        The default is ``None``.
     **kwargs
         Keyword arguments that are passed to ``matplotlib.pyplot.plot()``.
 
@@ -239,25 +291,36 @@ def group_delay(signal, unit=None, xscale='log', ax=None, style='light',
         >>> pf.plot.group_delay(impulse, unit='samples')
     """
 
+    # xscale deprecation
+    if xscale is not None:
+        warnings.warn(('The xscale parameter will be removed in'
+                       'pyfar 0.6.0. in favor of freq_scale'),
+                      PendingDeprecationWarning)
+        freq_scale = xscale
+
     with context(style):
-        ax = _line._group_delay(signal.flatten(), unit, xscale, ax, **kwargs)
+        ax = _line._group_delay(
+            signal.flatten(), unit, freq_scale, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
-        'group_delay', unit=unit, xscale=xscale)
-    interaction = ia.Interaction(signal, ax, style, plot_parameter, **kwargs)
+        'group_delay', unit_gd=unit, xscale=freq_scale)
+    interaction = ia.Interaction(
+        signal, ax, None, style, plot_parameter, **kwargs)
     ax.interaction = interaction
 
     return ax
 
 
 def time_freq(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
-              log_prefix_freq=None, log_reference=1, xscale='log', unit=None,
-              ax=None, style='light', **kwargs):
+              log_prefix_freq=None, log_reference=1, freq_scale='log',
+              unit=None, ax=None, style='light', xscale=None, **kwargs):
     """
-    Plot the time signal and magnitude spectrum in a 2 by 1 subplot layout.
+    Plot the time signal and magnitude spectrum (2 by 1 subplot).
 
+    Plots ``signal.time`` and ``abs(signal.freq)`` passes keyword arguments
+    (`kwargs`) to ``matplotlib.pyplot.plot()``.
 
     Parameters
     ----------
@@ -283,19 +346,30 @@ def time_freq(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
     log_reference : integer
         Reference for calculating the logarithmic time/frequency data.
         The default is ``1``.
-    xscale : str
+    freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
     unit : str
-        Unit of the time axis. Can be ``s``, ``ms``, ``mus``, or ``samples``.
+        Unit of the time axis. Can be ``'s'``, ``'ms'``, ``'mus'``, or
+        ``'samples'``.
         The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milli seconds), or ``mus`` (micro seconds) depending on the data.
+        (milliseconds), or ``mus`` (microseconds) depending on the data.
     ax : matplotlib.pyplot.axes
-        Axes to plot on. The default is ``None``, which uses the current axis
-        or creates a new figure if none exists.
+        Array or list with two axes to plot on. The default is ``None``, which
+        uses the current axis or creates a new figure if none exists.
     style : str
         ``light`` or ``dark`` to use the pyfar plot styles or a plot style from
         ``matplotlib.style.available``. The default is ``light``.
+    xscale : str
+
+        .. deprecated:: 0.4.0
+
+        This parameter was replaced by the more explicit ``freq_scale``,
+        which has the same functionality.
+        If not ``None``, it overwrites ``freq_scale``.
+        It is kept for backwards compatibility until pyfar version 0.6.0.
+
+        The default is ``None``.
     **kwargs
         Keyword arguments that are passed to ``matplotlib.pyplot.plot()``.
 
@@ -314,26 +388,38 @@ def time_freq(signal, dB_time=False, dB_freq=True, log_prefix_time=20,
         >>> pf.plot.time_freq(sine)
     """
 
+    # xscale deprecation
+    if xscale is not None:
+        warnings.warn(('The xscale parameter will be removed in'
+                       'pyfar 0.6.0. in favor of freq_scale'),
+                      PendingDeprecationWarning)
+        freq_scale = xscale
+
     with context(style):
         ax = _line._time_freq(signal.flatten(), dB_time, dB_freq,
                               log_prefix_time, log_prefix_freq,
-                              log_reference, xscale, unit, ax, **kwargs)
+                              log_reference, freq_scale, unit, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
-        'time', dB_time=dB_time, log_prefix_time=log_prefix_time,
-        log_prefix_freq=log_prefix_freq, log_reference=log_reference)
+        'time_freq', dB_time=dB_time, dB_freq=dB_freq,
+        log_prefix_time=log_prefix_time, log_prefix_freq=log_prefix_freq,
+        log_reference=log_reference, xscale=freq_scale, unit_time=unit)
     interaction = ia.Interaction(
-        signal, ax[0], style, plot_parameter, **kwargs)
+        signal, ax, None, style, plot_parameter, **kwargs)
     ax[0].interaction = interaction
 
     return ax
 
 
-def freq_phase(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
-               deg=False, unwrap=False, ax=None, style='light', **kwargs):
-    """Plot the magnitude and phase spectrum in a 2 by 1 subplot layout.
+def freq_phase(signal, dB=True, log_prefix=None, log_reference=1,
+               freq_scale='log', deg=False, unwrap=False, ax=None,
+               style='light', xscale=None, **kwargs):
+    """Plot the magnitude and phase spectrum (2 by 1 subplot).
+
+    Plots ``abs(signal.freq)`` and ``angle(signal.freq)`` and passes keyword
+    arguments (`kwargs`) to ``matplotlib.pyplot.plot()``.
 
     Parameters
     ----------
@@ -348,24 +434,34 @@ def freq_phase(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
     log_prefix : integer, float
         Prefix for calculating the logarithmic frequency data. The default is
         ``None``, so ``10`` is chosen if ``signal.fft_norm`` is ``'power'`` or
-        ``'psd'`` and ``20`` otherwise..
+        ``'psd'`` and ``20`` otherwise.
     log_reference : integer
         Reference for calculating the logarithmic frequency data. The default
         is ``1``.
     deg : bool
         Flag to plot the phase in degrees. The default is ``False``.
     unwrap : bool, str
-        True to unwrap the phase or "360" to unwrap the phase to 2 pi. The
+        True to unwrap the phase or ``'360'`` to unwrap the phase to 2 pi. The
         default is ``False``.
-    xscale : str
+    freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
     ax : matplotlib.pyplot.axes
-        Axes to plot on. The default is ``None``, which uses the current figure
-        ore creates a new one if no figure exists.
+        Array or list with two axes to plot on. The default is ``None``, which
+        uses the current axis or creates a new figure if none exists.
     style : str
         ``light`` or ``dark`` to use the pyfar plot styles or style from
         ``matplotlib.style.available``. The default is ``light``.
+    xscale : str
+
+        .. deprecated:: 0.4.0
+
+        This parameter was replaced by the more explicit ``freq_scale``,
+        which has the same functionality.
+        If not ``None``, it overwrites ``freq_scale``.
+        It is kept for backwards compatibility until pyfar version 0.6.0.
+
+        The default is ``None``.
     **kwargs
         Keyword arguments that are forwarded to matplotlib.pyplot.plot
 
@@ -374,37 +470,51 @@ def freq_phase(signal, dB=True, log_prefix=None, log_reference=1, xscale='log',
     ax : matplotlib.pyplot.axes
         Axes or array of axes containing the plot.
 
-    See Also
+    Examples
     --------
-    matplotlib.pyplot.plot() for possible **kwargs.
+
+    .. plot::
+
+        >>> import pyfar as pf
+        >>> impulse = pf.signals.impulse(100, 10)
+        >>> pf.plot.freq_phase(impulse, unwrap=True)
     """
 
+    # xscale deprecation
+    if xscale is not None:
+        warnings.warn(('The xscale parameter will be removed in'
+                       'pyfar 0.6.0. in favor of freq_scale'),
+                      PendingDeprecationWarning)
+        freq_scale = xscale
+
     with context(style):
         ax = _line._freq_phase(signal.flatten(), dB, log_prefix, log_reference,
-                               xscale, deg, unwrap, ax, **kwargs)
+                               freq_scale, deg, unwrap, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
-        'freq', dB_freq=dB, log_prefix_freq=log_prefix,
-        log_reference=log_reference, xscale=xscale)
+        'freq_phase', dB_freq=dB, log_prefix_freq=log_prefix,
+        log_reference=log_reference, xscale=freq_scale, deg=deg,
+        unwrap=unwrap)
     interaction = ia.Interaction(
-        signal, ax[0], style, plot_parameter, **kwargs)
+        signal, ax, None, style, plot_parameter, **kwargs)
     ax[0].interaction = interaction
 
     return ax
 
 
 def freq_group_delay(signal, dB=True, log_prefix=None, log_reference=1,
-                     unit=None, xscale='log', ax=None, style='light',
-                     **kwargs):
-    """Plot the magnitude and group delay spectrum in a 2 by 1 subplot layout.
+                     unit=None, freq_scale='log', ax=None, style='light',
+                     xscale=None, **kwargs):
+    """Plot the magnitude and group delay spectrum (2 by 1 subplot).
 
-    Passes keyword arguments (`kwargs`) to ``matplotlib.pyplot.plot()``.
+    Plots ``abs(signal.freq)`` and ``pyfar.dsp.group_delay(signal.freq)`` and
+    passes keyword arguments (`kwargs`) to ``matplotlib.pyplot.plot()``.
 
     Parameters
     ----------
-    signal : Signal, FrequencyData
+    signal : Signal
         The input data to be plotted. Multidimensional data are flattened for
         plotting, e.g, a signal of ``signal.cshape = (2, 2)`` would be plotted
         in the order ``(0, 0)``, ``(0, 1)``, ``(1, 0)``, ``(1, 1)``.
@@ -419,18 +529,29 @@ def freq_group_delay(signal, dB=True, log_prefix=None, log_reference=1,
         Reference for calculating the logarithmic frequency data. The default
         is ``1``.
     unit : str
-        Unit of the group delay. Can be ``s``, ``ms``, ``mus``, or ``samples``.
+        Unit of the group delay. Can be ``'s'``, ``'ms'``, ``'mus'``, or
+        ``'samples'``.
         The default is ``None``, which sets the unit to ``s`` (seconds), ``ms``
-        (milli seconds), or ``mus`` (micro seconds) depending on the data.
-    xscale : str
+        (milliseconds), or ``mus`` (microseconds) depending on the data.
+    freq_scale : str
         ``linear`` or ``log`` to plot on a linear or logarithmic frequency
         axis. The default is ``log``.
     ax : matplotlib.pyplot.axes
-        Axes to plot on. The default is ``None``, which uses the current axis
-        or creates a new figure if none exists.
+        Array or list with two axes to plot on. The default is ``None``, which
+        uses the current axis or creates a new figure if none exists.
     style : str
         ``light`` or ``dark`` to use the pyfar plot styles or a plot style from
         ``matplotlib.style.available``. The default is ``light``.
+    xscale : str
+
+        .. deprecated:: 0.4.0
+
+        This parameter was replaced by the more explicit ``freq_scale``,
+        which has the same functionality.
+        If not ``None``, it overwrites ``freq_scale``.
+        It is kept for backwards compatibility until pyfar version 0.6.0.
+
+        The default is ``None``.
     **kwargs
         Keyword arguments that are passed to ``matplotlib.pyplot.plot()``.
 
@@ -449,18 +570,25 @@ def freq_group_delay(signal, dB=True, log_prefix=None, log_reference=1,
         >>> pf.plot.freq_group_delay(impulse, unit='samples')
     """
 
+    # xscale deprecation
+    if xscale is not None:
+        warnings.warn(('The xscale parameter will be removed in'
+                       'pyfar 0.6.0. in favor of freq_scale'),
+                      PendingDeprecationWarning)
+        freq_scale = xscale
+
     with context(style):
         ax = _line._freq_group_delay(
             signal.flatten(), dB, log_prefix, log_reference,
-            unit, xscale, ax, **kwargs)
+            unit, freq_scale, ax, **kwargs)
     _utils._tight_layout()
 
     # manage interaction
     plot_parameter = ia.PlotParameter(
-        'freq', dB_freq=dB, log_prefix_freq=log_prefix,
-        log_reference=log_reference, xscale=xscale)
+        'freq_group_delay', dB_freq=dB, log_prefix_freq=log_prefix,
+        log_reference=log_reference, unit_gd=unit, xscale=freq_scale)
     interaction = ia.Interaction(
-        signal, ax[0], style, plot_parameter, **kwargs)
+        signal, ax, None, style, plot_parameter, **kwargs)
     ax[0].interaction = interaction
 
     return ax
